.. pyLARDA documentation master file, created by
   sphinx-quickstart on Sun Dec  2 22:49:08 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


pyLARDA documentation
==================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   Overview <README.md>
   how_to_use.rst
   datacontainer_and_transformation.rst
   guide_config.rst
   setup_remote.rst
   peakTree.rst
   spectra.rst
   api_overview.rst
   contributors.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
